@@ -13,7 +13,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include <config.h>
 
@@ -208,7 +208,7 @@ mark_border (loc)
   for (i = 0; i < 8; i++)
     {
       Coord this_coord;
-      this_coord = add_coord (loc, round[i]);
+      this_coord = add_coord (loc, round_game[i]);
       get_map_real_coord (&this_coord);
       if (this_coord.x != -1)
 	{
@@ -329,7 +329,7 @@ count_connects (loc, pattern, array)
   for (i = 0; i < 8; i++)
     {
       Coord this_loc;
-      this_loc = add_coord(loc, round[i]);
+      this_loc = add_coord(loc, round_game[i]);
       get_map_real_coord (&this_loc);
       if (this_loc.x != -1)
 	{
@@ -605,7 +605,7 @@ search_contact (loc)
 	  for (i = 0; i < 8; i++)
 	    {
 	      Coord neighbour;
-	      neighbour = add_coord (loc, round[i]);
+	      neighbour = add_coord (loc, round_game[i]);
 	      get_map_real_coord (&neighbour);
 	      if (neighbour.x != -1)
 		{
